# PropelAuth Python SDK

<p align="center">
  <a href="https://www.propelauth.com/?utm_campaign=github-python" target="_blank" align="center">
    <img src="https://propelauth-logos.s3.us-west-2.amazonaws.com/logo-only.png" width="100">
  </a>
</p>


A python library for managing authentication, backed by [PropelAuth](https://www.propelauth.com/?utm_campaign=github-python). 

[PropelAuth](https://www.propelauth.com?ref=github) makes it easy to add authentication and authorization to your B2B/multi-tenant application.

Your frontend gets a beautiful, safe, and customizable login screen. Your backend gets easy authorization with just a few lines of code. You get an easy-to-use dashboard to config and manage everything.

## Documentation

- Full reference this library is [here](https://docs.propelauth.com/reference/backend-apis/python)
- Getting started guides for PropelAuth are [here](https://docs.propelauth.com/)

## Questions?

Feel free to reach out at support@propelauth.com
